@@ -3,7 +3,6 @@ package oscommands
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 )
@@ -39,13 +38,13 @@ import (
 func CopyFile(src, dst string) (err error) {
 	in, err := os.Open(src)
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 	defer in.Close()
 
 	out, err := os.Create(dst)
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 	defer func() {
 		if e := out.Close(); e != nil {
@@ -55,21 +54,21 @@ func CopyFile(src, dst string) (err error) {
 
 	_, err = io.Copy(out, in)
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 
 	err = out.Sync()
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 
 	si, err := os.Stat(src)
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 	err = os.Chmod(dst, si.Mode())
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 
 	return //nolint: nakedret
@@ -92,7 +91,7 @@ func CopyDir(src string, dst string) (err error) {
 
 	_, err = os.Stat(dst)
 	if err != nil && !os.IsNotExist(err) {
-		return
+		return //nolint: nakedret
 	}
 	if err == nil {
 		// it exists so let's remove it
@@ -103,12 +102,12 @@ func CopyDir(src string, dst string) (err error) {
 
 	err = os.MkdirAll(dst, si.Mode())
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 
-	entries, err := ioutil.ReadDir(src)
+	entries, err := os.ReadDir(src)
 	if err != nil {
-		return
+		return //nolint: nakedret
 	}
 
 	for _, entry := range entries {
@@ -118,17 +117,23 @@ func CopyDir(src string, dst string) (err error) {
 		if entry.IsDir() {
 			err = CopyDir(srcPath, dstPath)
 			if err != nil {
-				return
+				return //nolint: nakedret
 			}
 		} else {
+			var info os.FileInfo
+			info, err = entry.Info()
+			if err != nil {
+				return //nolint: nakedret
+			}
+
 			// Skip symlinks.
-			if entry.Mode()&os.ModeSymlink != 0 {
+			if info.Mode()&os.ModeSymlink != 0 {
 				continue
 			}
 
 			err = CopyFile(srcPath, dstPath)
 			if err != nil {
-				return
+				return //nolint: nakedret
 			}
 		}
 	}
