@@ -13,7 +13,6 @@ import (
 	"github.com/samber/lo"
 
 	"github.com/atotto/clipboard"
-	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/kill"
 	"github.com/jesseduffield/lazygit/pkg/common"
 	"github.com/jesseduffield/lazygit/pkg/config"
@@ -118,7 +117,15 @@ func (c *OSCommand) Quote(message string) string {
 
 // AppendLineToFile adds a new line in file
 func (c *OSCommand) AppendLineToFile(filename, line string) error {
-	c.LogCommand(fmt.Sprintf("Appending '%s' to file '%s'", line, filename), false)
+	msg := utils.ResolvePlaceholderString(
+		c.Tr.Log.AppendingLineToFile,
+		map[string]string{
+			"line":     line,
+			"filename": filename,
+		},
+	)
+	c.LogCommand(msg, false)
+
 	f, err := os.OpenFile(filename, os.O_APPEND|os.O_RDWR|os.O_CREATE, 0o600)
 	if err != nil {
 		return utils.WrapError(err)
@@ -155,7 +162,13 @@ func (c *OSCommand) AppendLineToFile(filename, line string) error {
 
 // CreateFileWithContent creates a file with the given content
 func (c *OSCommand) CreateFileWithContent(path string, content string) error {
-	c.LogCommand(fmt.Sprintf("Creating file '%s'", path), false)
+	msg := utils.ResolvePlaceholderString(
+		c.Tr.Log.CreateFileWithContent,
+		map[string]string{
+			"path": path,
+		},
+	)
+	c.LogCommand(msg, false)
 	if err := os.MkdirAll(filepath.Dir(path), os.ModePerm); err != nil {
 		c.Log.Error(err)
 		return err
@@ -171,7 +184,13 @@ func (c *OSCommand) CreateFileWithContent(path string, content string) error {
 
 // Remove removes a file or directory at the specified path
 func (c *OSCommand) Remove(filename string) error {
-	c.LogCommand(fmt.Sprintf("Removing '%s'", filename), false)
+	msg := utils.ResolvePlaceholderString(
+		c.Tr.Log.Remove,
+		map[string]string{
+			"filename": filename,
+		},
+	)
+	c.LogCommand(msg, false)
 	err := os.RemoveAll(filename)
 	return utils.WrapError(err)
 }
@@ -189,7 +208,7 @@ func (c *OSCommand) FileExists(path string) (bool, error) {
 
 // PipeCommands runs a heap of commands and pipes their inputs/outputs together like A | B | C
 func (c *OSCommand) PipeCommands(cmdObjs ...ICmdObj) error {
-	cmds := slices.Map(cmdObjs, func(cmdObj ICmdObj) *exec.Cmd {
+	cmds := lo.Map(cmdObjs, func(cmdObj ICmdObj, _ int) *exec.Cmd {
 		return cmdObj.GetCmd()
 	})
 
@@ -266,12 +285,32 @@ func PrepareForChildren(cmd *exec.Cmd) {
 func (c *OSCommand) CopyToClipboard(str string) error {
 	escaped := strings.Replace(str, "\n", "\\n", -1)
 	truncated := utils.TruncateWithEllipsis(escaped, 40)
-	c.LogCommand(fmt.Sprintf("Copying '%s' to clipboard", truncated), false)
+
+	msg := utils.ResolvePlaceholderString(
+		c.Tr.Log.CopyToClipboard,
+		map[string]string{
+			"str": truncated,
+		},
+	)
+	c.LogCommand(msg, false)
+	if c.UserConfig.OS.CopyToClipboardCmd != "" {
+		cmdStr := utils.ResolvePlaceholderString(c.UserConfig.OS.CopyToClipboardCmd, map[string]string{
+			"text": c.Cmd.Quote(str),
+		})
+		return c.Cmd.NewShell(cmdStr).Run()
+	}
+
 	return clipboard.WriteAll(str)
 }
 
 func (c *OSCommand) RemoveFile(path string) error {
-	c.LogCommand(fmt.Sprintf("Deleting path '%s'", path), false)
+	msg := utils.ResolvePlaceholderString(
+		c.Tr.Log.RemoveFile,
+		map[string]string{
+			"path": path,
+		},
+	)
+	c.LogCommand(msg, false)
 
 	return c.removeFileFn(path)
 }
