@@ -16,6 +16,9 @@ type BaseContext struct {
 	keybindingsFns      []types.KeybindingsFn
 	mouseKeybindingsFns []types.MouseKeybindingsFn
 	onClickFn           func() error
+	onRenderToMainFn    func() error
+	onFocusFn           onFocusFn
+	onFocusLostFn       onFocusLostFn
 
 	focusable           bool
 	transient           bool
@@ -25,6 +28,11 @@ type BaseContext struct {
 	*ParentContextMgr
 }
 
+type (
+	onFocusFn     = func(types.OnFocusOpts) error
+	onFocusLostFn = func(types.OnFocusLostOpts) error
+)
+
 var _ types.IBaseContext = &BaseContext{}
 
 type NewBaseContextOpts struct {
@@ -129,6 +137,36 @@ func (self *BaseContext) GetOnClick() func() error {
 	return self.onClickFn
 }
 
+func (self *BaseContext) AddOnRenderToMainFn(fn func() error) {
+	if fn != nil {
+		self.onRenderToMainFn = fn
+	}
+}
+
+func (self *BaseContext) GetOnRenderToMain() func() error {
+	return self.onRenderToMainFn
+}
+
+func (self *BaseContext) AddOnFocusFn(fn onFocusFn) {
+	if fn != nil {
+		self.onFocusFn = fn
+	}
+}
+
+func (self *BaseContext) GetOnFocus() onFocusFn {
+	return self.onFocusFn
+}
+
+func (self *BaseContext) AddOnFocusLostFn(fn onFocusLostFn) {
+	if fn != nil {
+		self.onFocusLostFn = fn
+	}
+}
+
+func (self *BaseContext) GetOnFocusLost() onFocusLostFn {
+	return self.onFocusLostFn
+}
+
 func (self *BaseContext) GetMouseKeybindings(opts types.KeybindingsOpts) []*gocui.ViewMouseBinding {
 	bindings := []*gocui.ViewMouseBinding{}
 	for i := range self.mouseKeybindingsFns {
