@@ -31,6 +31,7 @@ func NewBranchesContext(c *ContextCommon) *BranchesContext {
 			c.Modes().Diffing.Ref,
 			c.Tr,
 			c.UserConfig,
+			c.Model().Worktrees,
 		)
 	}
 
@@ -82,3 +83,7 @@ func (self *BranchesContext) GetDiffTerminals() []string {
 	}
 	return nil
 }
+
+func (self *BranchesContext) ShowBranchHeadsInSubCommits() bool {
+	return true
+}
