@@ -37,6 +37,13 @@ func NewSubCommitsContext(
 	}
 
 	getDisplayStrings := func(startIdx int, length int) [][]string {
+		// This can happen if a sub-commits view is asked to be rerendered while
+		// it is invisble; for example when switching screen modes, which
+		// rerenders all views.
+		if viewModel.GetRef() == nil {
+			return [][]string{}
+		}
+
 		selectedCommitSha := ""
 		if c.CurrentContext().GetKey() == SUB_COMMITS_CONTEXT_KEY {
 			selectedCommit := viewModel.GetSelected()
@@ -44,12 +51,21 @@ func NewSubCommitsContext(
 				selectedCommitSha = selectedCommit.Sha
 			}
 		}
+		branches := []*models.Branch{}
+		if viewModel.GetShowBranchHeads() {
+			branches = c.Model().Branches
+		}
+		showBranchMarkerForHeadCommit := c.Git().Config.GetRebaseUpdateRefs()
 		return presentation.GetCommitListDisplayStrings(
 			c.Common,
 			c.Model().SubCommits,
+			branches,
+			viewModel.GetRef().RefName(),
+			showBranchMarkerForHeadCommit,
 			c.State().GetRepoState().GetScreenMode() != types.SCREEN_NORMAL,
 			c.Modes().CherryPicking.SelectedShaSet(),
 			c.Modes().Diffing.Ref,
+			"",
 			c.UserConfig.Gui.TimeFormat,
 			c.UserConfig.Gui.ShortTimeFormat,
 			time.Now(),
@@ -97,7 +113,8 @@ type SubCommitsViewModel struct {
 	ref types.Ref
 	*ListViewModel[*models.Commit]
 
-	limitCommits bool
+	limitCommits    bool
+	showBranchHeads bool
 }
 
 func (self *SubCommitsViewModel) SetRef(ref types.Ref) {
@@ -108,6 +125,14 @@ func (self *SubCommitsViewModel) GetRef() types.Ref {
 	return self.ref
 }
 
+func (self *SubCommitsViewModel) SetShowBranchHeads(value bool) {
+	self.showBranchHeads = value
+}
+
+func (self *SubCommitsViewModel) GetShowBranchHeads() bool {
+	return self.showBranchHeads
+}
+
 func (self *SubCommitsContext) GetSelectedItemId() string {
 	item := self.GetSelected()
 	if item == nil {
