@@ -1,13 +1,13 @@
 package presentation
 
 import (
-	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/theme"
+	"github.com/samber/lo"
 )
 
 func GetSubmoduleListDisplayStrings(submodules []*models.SubmoduleConfig) [][]string {
-	return slices.Map(submodules, func(submodule *models.SubmoduleConfig) []string {
+	return lo.Map(submodules, func(submodule *models.SubmoduleConfig, _ int) []string {
 		return getSubmoduleDisplayStrings(submodule)
 	})
 }
