@@ -6,12 +6,14 @@ type RefreshableView int
 const (
 	COMMITS RefreshableView = iota
 	REBASE_COMMITS
+	SUB_COMMITS
 	BRANCHES
 	FILES
 	STASH
 	REFLOG
 	TAGS
 	REMOTES
+	WORKTREES
 	STATUS
 	SUBMODULES
 	STAGING
@@ -32,6 +34,6 @@ const (
 
 type RefreshOptions struct {
 	Then  func()
-	Scope []RefreshableView // e.g. []int{COMMITS, BRANCHES}. Leave empty to refresh everything
+	Scope []RefreshableView // e.g. []RefreshableView{COMMITS, BRANCHES}. Leave empty to refresh everything
 	Mode  RefreshMode       // one of SYNC (default), ASYNC, and BLOCK_UI
 }
