@@ -10,7 +10,6 @@ import (
 	"bytes"
 	"errors"
 	"io"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"testing"
@@ -40,6 +39,12 @@ func TestIntegration(t *testing.T) {
 				return
 			}
 
+			// not running demoes right now. Arguably we should, but we'd need to
+			// strip away any artificial lag they use.
+			if test.IsDemo() {
+				return
+			}
+
 			t.Run(test.Name(), func(t *testing.T) {
 				t.Parallel()
 				err := f()
@@ -76,7 +81,7 @@ func runCmdHeadless(cmd *exec.Cmd) error {
 		return err
 	}
 
-	_, _ = io.Copy(ioutil.Discard, f)
+	_, _ = io.Copy(io.Discard, f)
 
 	if cmd.Wait() != nil {
 		// return an error with the stderr output
