@@ -20,7 +20,7 @@ func (self *CommitDescriptionPanelDriver) SwitchToSummary() *CommitMessagePanelD
 }
 
 func (self *CommitDescriptionPanelDriver) AddNewline() *CommitDescriptionPanelDriver {
-	self.t.press(self.t.keys.Universal.Confirm)
+	self.t.pressFast(self.t.keys.Universal.Confirm)
 	return self
 }
 
